@@ -10,6 +10,7 @@
 
 #include <QDir>
 #include <QUrl>
+#include <ranges>
 
 #include "fileCleaner.h"
 #include "filelight_debug.h"
@@ -54,7 +55,7 @@ QUrl File::url(const std::shared_ptr<Folder> &root) const
     return QUrl::fromUserInput(path, QString(), QUrl::AssumeLocalFile);
 }
 
-void Folder::clone(const Folder *that, std::shared_ptr<Folder> other)
+void Folder::clone(const Folder *that, const std::shared_ptr<Folder> &other)
 {
     struct Clone {
         const Folder *source;
@@ -62,7 +63,7 @@ void Folder::clone(const Folder *that, std::shared_ptr<Folder> other)
         std::shared_ptr<Folder> parent;
     };
     QList<Clone> completedClones;
-    QList<Clone> clones({{that, other, nullptr}});
+    QList<Clone> clones({Clone{.source = that, .target = other, .parent = nullptr}});
     while (!clones.isEmpty()) {
         const auto &clone = clones.takeLast();
         qCDebug(FILELIGHT_LOG) << "cloning" << clone.source->m_name << clone.source << "into" << clone.target.get() << "parent" << clone.parent.get();
@@ -70,17 +71,16 @@ void Folder::clone(const Folder *that, std::shared_ptr<Folder> other)
             qCDebug(FILELIGHT_LOG) << "  " << file->displayName() << file->isFolder();
             if (file->isFolder()) {
                 auto folder = std::dynamic_pointer_cast<Folder>(file);
-                clones.append(Clone{folder.get(), std::make_shared<Folder>(folder->m_name.constData()), clone.target});
+                clones.append(Clone{.source = folder.get(), .target = std::make_shared<Folder>(folder->m_name.constData()), .parent = clone.target});
             } else {
                 clone.target->append(file->m_name.constData(), file->m_size);
             }
         }
         completedClones.append(clone);
     }
-    for (auto it = completedClones.rbegin(); it != completedClones.rend(); ++it) {
+    for (const auto &clone : std::ranges::reverse_view(completedClones)) {
         // Appending forwards the size data, it must only happen after all duplicating is done so the sizes are known.
         // And obviously in reverse order of existence in the tree.
-        auto clone = *it;
         if (clone.parent) {
             clone.parent->append(clone.target);
         }
